@@ -1,6 +1,6 @@
 /* FNA3D - 3D Graphics Library for FNA
  *
- * Copyright (c) 2020-2023 Ethan Lee
+ * Copyright (c) 2020-2024 Ethan Lee
  *
  * This software is provided 'as-is', without any express or implied warranty.
  * In no event will the authors be held liable for any damages arising from
@@ -35,6 +35,12 @@
 #define FNA3DCALL
 #endif
 
+#ifdef _MSC_VER
+#define FNA3DDEPRECATED(msg) __declspec(deprecated(msg))
+#else
+#define FNA3DDEPRECATED(msg) __attribute__((deprecated(msg)))
+#endif
+
 /* -Wpedantic nameless union/struct silencing */
 #ifndef FNA3DNAMELESS
 #ifdef __GNUC__
@@ -462,8 +468,8 @@ typedef struct FNA3D_RenderTargetBinding
 /* Version API */
 
 #define FNA3D_ABI_VERSION	 0
-#define FNA3D_MAJOR_VERSION	23
-#define FNA3D_MINOR_VERSION	 7
+#define FNA3D_MAJOR_VERSION	24
+#define FNA3D_MINOR_VERSION	 3
 #define FNA3D_PATCH_VERSION	 0
 
 #define FNA3D_COMPILED_VERSION ( \
@@ -503,6 +509,8 @@ FNA3DAPI void FNA3D_HookLogFunctions(
 FNA3DAPI uint32_t FNA3D_PrepareWindowAttributes(void);
 
 /* After your device is created, call this to check for high-DPI support.
+ *
+ * NOTE: This call is now deprecated, in favor of SDL_GetWindowSizeInPixels!
  *
  * Note that this will NOT work if it's called after the window is created but
  * before the device! Not all platforms create drawable surfaces at the same
@@ -512,6 +520,7 @@ FNA3DAPI uint32_t FNA3D_PrepareWindowAttributes(void);
  * w:		Filled with the width of the window's drawable canvas.
  * h:		Filled with the height of the window's drawable canvas.
  */
+FNA3DDEPRECATED("Use SDL_GetWindowSizeInPixels instead!")
 FNA3DAPI void FNA3D_GetDrawableSize(void* window, int32_t *w, int32_t *h);
 
 /* Creates a rendering context for use on the calling thread.
@@ -1521,6 +1530,14 @@ FNA3DAPI int32_t FNA3D_GetMaxMultiSampleCount(
  */
 FNA3DAPI void FNA3D_SetStringMarker(FNA3D_Device *device, const char *text);
 
+/* Sets an arbitrary string constant to be stored in a rendering API trace,
+ * useful for labeling textures for debugging purposes.
+ *
+ * texture: The texture to attach the name to.
+ * text: The string constant to mark as the name of the texture.
+ */
+FNA3DAPI void FNA3D_SetTextureName(FNA3D_Device *device, FNA3D_Texture *texture, const char *text);
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
